@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.032-6-g8260f8c
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.033-3-gcf5e48a
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::Plugin::PromptIfStale::VERSION = '0.033';
+$Dist::Zilla::Plugin::PromptIfStale::VERSION = '0.034';
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
     'Dist::Zilla::Role::AfterBuild',
@@ -12,7 +12,7 @@ with 'Dist::Zilla::Role::BeforeBuild',
 
 use Moose::Util::TypeConstraints;
 use MooseX::Types::Moose qw(ArrayRef Bool Str);
-use List::Util 1.33 'none';
+use List::Util 1.33 qw(none any);
 use List::MoreUtils 'uniq';
 use version;
 use Path::Tiny;
@@ -153,6 +153,14 @@ sub stale_modules
         $already_checked{$module}++ if $module eq 'perl';
         next if $already_checked{$module};
 
+        # these core modules should be indexed, but aren't
+        if (any { $module eq $_ } qw(Config DB Errno integer NEXT Pod::Functions))
+        {
+            $self->log_debug([ 'skipping core module: %s', $module ]);
+            $already_checked{$module}++;
+            next;
+        }
+
         my $path = module_path($module);
         if (not $path)
         {
@@ -439,7 +447,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
